@@ -17,14 +17,14 @@
 
 #include "k3b_export.h"
 
-#include <QtCore/QString>
+#include <QString>
 
 namespace K3b {
     class LIBK3B_EXPORT FileSystemInfo
     {
     public:
         FileSystemInfo();
-        FileSystemInfo( const QString& path );
+        explicit FileSystemInfo( const QString& path );
         FileSystemInfo( const FileSystemInfo& );
         ~FileSystemInfo();
 
