@@ -17,9 +17,9 @@
 #define _K3B_MSF_H_
 
 #include "k3bdevice_export.h"
-#include <KIOCore/KIO/Global>
-#include <QtCore/QDebug>
-#include <QtCore/QSharedDataPointer>
+#include <KIO/Global>
+#include <QDebug>
+#include <QSharedDataPointer>
 
 namespace K3b
 {
